@@ -1,12 +1,15 @@
 
 #' Complex Preferences
 #' 
-#' Complex preferences are used to compose different preference orders. For example the Pareto composition (via operator \code{*}) is the usual operator
+#' Complex preferences are used to compose different preference orders. 
+#' For example the Pareto composition (via operator \code{*}) is the usual operator
 #' to compose the preference for a Skyline query. The Skyline is also known as Pareto frontier.
 #' All complex preferences are mathematically strict partial orders (irreflexive and transitive).
 #' 
 #' @name complex_pref
-#' @param p,p1,p2,x Preferences (they can be either base preferences, see \code{\link{base_pref}}, or complex preferences)
+#' @param p,p1,p2,x Preferences (they can be either base preferences, see \code{\link{base_pref}}, or complex preferences),
+#'                  or, for \code{is.complex_pref}, an object to be tested if it is a complex preference.
+#'                
 #' 
 #' @section Skylines:
 #' 
@@ -62,18 +65,16 @@
 #'  \item{\code{reverse(p1)} or \code{-p1}}{Reverse preference (converse relation): 
 #'  A tuple t1 is better than t2 w.r.t. \code{-p1} if t2 is better than t1 w.r.t. \code{p1}. 
 #'  The unary minus operator, i.e. \code{-p1}, is a short hand notation for \code{reverse(p1)}.}
-#'  \item{\code{empty()}}{Empty preference, i.e., a neutral element for the complex preference compositions \code{{*, &, +}}. 
-#'  It holds that \code{empty() * p} and \code{empty() & p} is equal to \code{p} for all preferences \code{p}.}
 #' }
 #' 
-#' @section Preference Term Length:
+#' The function \code{is.complex_pref} returns \code{TRUE} if \code{x} is a complex preference object 
+#' (i.e., was constructed by one of these binary operators or the unary operator \code{reverse}) 
+#' and \code{FALSE} otherwise.
 #' 
-#' The function \code{length(p)} returns the term length of the preference term \code{p} which is defined as the number of base preferences
-#' in a complex preference term.
 #'
-#' @seealso See \code{\link{base_pref}} for the construction of base preferences. See \code{\link{psel}} for the evaluation of preferences. 
-#' 
-#' @keywords skyline
+#' @seealso See \code{\link{base_pref}} for the construction of base preferences. 
+#' See \code{\link{general_pref}} for functions applicable to all kind of preferences.
+#' See \code{\link{psel}} for the evaluation of preferences. 
 #' 
 #' @references 
 #' 
@@ -86,7 +87,7 @@
 #' 
 #' @examples
 #' # define preference for cars with low consumption (high mpg-value) 
-#' # and simultanously high horsepower
+#' # and simultaneously high horsepower
 #' p1 <- high(mpg) * high(hp)  
 #' 
 #' # perform the preference search
@@ -142,28 +143,24 @@ NULL
 #' @export
 reverse <- function(p) {
   check_pref(p)
-  if (is.emptypref(p)) return(p)
+  if (is.empty_pref(p)) return(p)
   return(reversepref(p))
 }
 
-# This entry will be deleted in the final man-files as "-" is just used unary!
-#' @rdname complex_pref
+# This entry has no @rdname as "-" is just used unary!
+# (it is exported, but invisible in the documentation
 #' @export
 "-.preference" <- function(p1, p2) {
   if (nargs() == 1) return(reverse(p1))
   else stop("Operation not defined.")
 }
 
-# Neutral element
+
 #' @rdname complex_pref
 #' @export
-empty <- function() emptypref()
-
-# Length of a preference term (number of base preferences)
-#' @export
-#' @rdname complex_pref
-length.preference <- function(x) x$get_length()
-
+is.complex_pref <- function(x) {
+  return(inherits(x, "complexpref") || inherits(x, "reversepref"))
+}
  
 # Helper functions
 # ----------------
@@ -175,11 +172,11 @@ check_pref <- function(p1, p2) {
 }
 
 # Check if one (or perhaps both) preference is empty
-check_empty <- function(p1, p2) (is.emptypref(p1) || is.emptypref(p2))
+check_empty <- function(p1, p2) (is.empty_pref(p1) || is.empty_pref(p2))
 
 # Get the result of a complex operation with an empty pref
 get_empty <- function(p1, p2) {
-  if (is.emptypref(p1))
+  if (is.empty_pref(p1))
     return(p2) # perhaps empty
   else
     return(p1)
