@@ -77,6 +77,7 @@ preference <- setRefClass("preference",
     # All succesors/predecessors (sorting not necessary because of "which")
     all_predsucc = function(inds, do_intersect, succ) {
       .self$check_cache()
+      # does not need hasse diagram, but needs .self$scorevals
       
       # Select indices predecessors/successors
       if (succ) {
@@ -409,7 +410,7 @@ is.reversepref <- function(x) inherits(x, "reversepref")
 #' @export
 as.expression.reversepref <- function(x, ...) {
     # x is a base preference OR complex preference
-  return(as.expression(call('reverse', as.expression(x$p, ...)[[1]])))
+  return(as.expression(call('-', as.expression(x$p, ...)[[1]])))
 }
 
 # Binary complex preferences
